@@ -1029,26 +1029,36 @@ void EatStatement (PINPUTBUF pib)
 
 void GetStatement (PINPUTBUF pibIn, PSTR szStmt)
 {
-  char c;
-  int i, fDone = 0;
+  int i = 0;
+  int fDone = 0;
+  int iParCount = 0 ;    /* parentheses counter */
+  BOOL bParOpen = FALSE; /* True if a parenthesis is still open */
 
   if (!pibIn || !szStmt)
     return;
 
   SkipWhitespace (pibIn);
 
-  i = 0;
   if (!EOB(pibIn)) {
-    c = *pibIn->pbufCur;
     while (!fDone) {
       if (*pibIn->pbufCur) {
-        if (!(fDone = (NextChar (pibIn) == CH_STMTTERM))) {
+        /* Stop if end of statement found and parentheses are balanced */
+        if (!(fDone = ((NextChar(pibIn) == CH_STMTTERM) && !bParOpen))) {
           if (i < MAX_EQN - 2) {
             if ((szStmt[i++] = *pibIn->pbufCur++) == CH_EOLN)
               pibIn->iLineNum++;
+            if ((char) szStmt[i-1] == '(') {
+               iParCount++;
+               bParOpen = TRUE;
+            }
+            if ((char) szStmt[i-1] == ')') iParCount--;
+            if ((iParCount == 0) && bParOpen) bParOpen = FALSE;
           } /* if */
           else {
-            ReportError (pibIn, RE_EQNTOOLONG | RE_FATAL, NULL, NULL);
+            if (bParOpen)
+              ReportError (pibIn, RE_UNBALPAR | RE_FATAL, NULL, NULL);
+            else
+              ReportError (pibIn, RE_EQNTOOLONG | RE_FATAL, NULL, NULL);
           }
         }
       } /* if pibIn->pbufCur */
