@@ -57,9 +57,9 @@ void ReportError (PINPUTBUF pibIn, WORD wCode, PSTR szMsg, PSTR szAltMsg)
 
   if (wCode) {
     if (bWarning)
-      printf ("Warning: ");
+      printf ("*** Warning: ");
     else {
-      printf ("Error: ");
+      printf ("*** Error: ");
       bFatal |= (pibIn && (pibIn->cErrors++ > MAX_ERRORS));
     } /* else */
   } /* if */
@@ -167,14 +167,18 @@ void ReportError (PINPUTBUF pibIn, WORD wCode, PSTR szMsg, PSTR szAltMsg)
     printf ("Name %s exceed %d characters.", szMsg, MAX_NAME);
     break;
 
+  case RE_UNBALPAR:
+    printf ("Unbalanced parentheses at this line or above.");
+    break;
+
   } /* switch */
 
-  printf ("\n");
+  printf ("\n\n");
   if (szAltMsg && wCode != RE_LEXEXPECTED)
     printf ("%s\n", szAltMsg);
 
   if (bFatal) {
-    printf ("One or more fatal errors: Exiting...\n");
+    printf ("One or more fatal errors: Exiting...\n\n");
 
 #ifdef _MACOS_
     getchar();
