@@ -5,6 +5,20 @@
    
    Copyright (c) 1993.  Don Maszle, Frederic Bois.  All rights reserved.
 
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
    -- Revisions -----
      Logfile:  %F%
     Revision:  %I%
@@ -40,13 +54,8 @@
 #include "strutil.h"
 #include "lexerr.h"
 
-#ifdef MODGEN
 #include "mod.h"
 
-#else
-#include "modiface.h"
-#endif
- 
 
 /* Macros */
 
@@ -190,12 +199,18 @@ BOOL GetInputArgs (PINPUTBUF pibIn, PIFN pifn)
 {
   PSTRLEX rgszLex[4];
   int rgiTypes[4], i;
+  long rgiLowerB[4], rgiUpperB[4];
   BOOL bReturn = FALSE;
 
   for (i = 0; i < 4; i++)
     rgiTypes[i] = LX_INTEGER | LX_FLOAT | LX_IDENTIFIER;
 
-  if (GetFuncArgs (pibIn, 4, rgiTypes, rgszLex[0])) {
+  if (GetFuncArgs (pibIn, 4, rgiTypes, rgszLex[0], rgiLowerB, rgiUpperB)) {
+
+    for (i = 0; i < 4; i++)
+      if ((rgiLowerB[i] != -1) || (rgiUpperB[i] != -1))
+        ReportError (pibIn, RE_BADCONTEXT | RE_FATAL, "array bounds", 
+                     "Arrays cannot be used as input function parameters");
     
     /* Try to get each parm to show all errors */
     bReturn = TRUE;
