@@ -39,8 +39,8 @@
 /* ----- Constants  */
 
 /* Version and copyright */
-#define VSZ_VERSION "v5.0.0"
-#define VSZ_COPYRIGHT "Copyright (c) 1993-2004 by F. Bois & D. Maszle.  All rights reserved."
+#define VSZ_VERSION "v5.1.0"
+#define VSZ_COPYRIGHT "Copyright (c) 1993-2006 by F. Bois & D. Maszle.  All rights reserved."
 
 /* The time variable accessible to the user */
 #define VSZ_TIME "t"
@@ -57,6 +57,7 @@
 #define KM_JACOB       6
 #define KM_CALCOUTPUTS 7
 #define KM_DXDT        20
+#define KM_INLINE      30
 #define KM_END         100
 
 /* Context Types bit flags */
@@ -98,6 +99,7 @@
 #define ID_LOCALJACOB   0x7000 /* Local variables in Jacobian */
 #define ID_LOCALCALCOUT 0x8000 /* Local variables in CalcOutputs */
 #define ID_DERIV        0x9000 /* Derivative eqn in CalcDeriv */
+#define ID_INLINE       0xA000 /* Inline statement */
 
 /* ----- Enumerations */
 
