@@ -350,8 +350,11 @@ void DefineGlobalVar (PINPUTBUF pibIn, PVMMAPSTRCT pvm,
 {
   PINPUTINFO pinfo = (PINPUTINFO) pibIn->pInfo;
 
-  switch (hType) {
-      
+  if (!strcmp (szName, "Inline")) /* Inline statements are accumulated */
+    AddEquation (&pinfo->pvmGloVars, szName, szEqn, ID_INLINE);
+
+  else switch (hType) {
+
   case ID_NULL:
     AddEquation (&pinfo->pvmGloVars, szName, szEqn, ID_PARM);
     break;
@@ -378,7 +381,7 @@ void DefineGlobalVar (PINPUTBUF pibIn, PVMMAPSTRCT pvm,
       break;
     } /* if */
 
-    /* else  Redefinition -- Fall through ! */
+    /* else Redefinition -- Fall through ! */
 
   case ID_PARM:
     ReportError (pibIn, RE_REDEF | RE_WARNING, szName, NULL);
@@ -408,11 +411,13 @@ void DefineDynamicsEqn (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, HANDLE hType)
  
   /* If there was more than one line since last equation, set ID_SPACEFLAG. 
      This is kind of a kludge so I can use PVMMAPSTRCT struct. */
-
   if (pibIn->iLineNum - pibIn->iLNPrev - 1)
     hNewType |= ID_SPACEFLAG;
 
-  switch (hType) {
+  if (!strcmp (szName, "Inline")) /* Inline statements are accumulated */
+    AddEquation (&pinfo->pvmDynEqns, szName, szEqn, ID_INLINE);
+
+  else switch (hType) {
       
     case ID_NULL:
       AddEquation (&pinfo->pvmGloVars, szName, NULL, hNewType);
@@ -455,19 +460,24 @@ void DefineScaleEqn (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, HANDLE hType)
 
   /* If there was more than one line since last equation, set ID_SPACEFLAG.  
      This is kind of a kludge so I can use PVMMAPSTRCT struct. */
-
   if (pibIn->iLineNum - pibIn->iLNPrev - 1)
     hNewType |= ID_SPACEFLAG;
 
-  if (!hType) /* Original type is NULL */
-    AddEquation (&pinfo->pvmGloVars, szName, NULL, hNewType);
+  if (!strcmp (szName, "Inline")) /* Inline statements are accumulated */
+    AddEquation (&pinfo->pvmScaleEqns, szName, szEqn, ID_INLINE);
+
+  else {
+
+    if (!hType) /* Original type is NULL */
+      AddEquation (&pinfo->pvmGloVars, szName, NULL, hNewType);
+
+    if ((hType & ID_LOCALSCALE) || /* Many per local */
+        !GetVarPTR (pinfo->pvmScaleEqns, szName)) /* 1 eqn per parm */
+      AddEquation (&pinfo->pvmScaleEqns, szName, szEqn, hNewType);
     
-  if ((hType & ID_LOCALSCALE) /* Many per local */
-      || !GetVarPTR (pinfo->pvmScaleEqns, szName)) /* 1 eqn per parm */
-    AddEquation (&pinfo->pvmScaleEqns, szName, szEqn, hNewType);
-    
-  else
-    ReportError (pibIn, RE_REDEF | RE_WARNING, szName, "* Ignoring");    
+    else
+      ReportError (pibIn, RE_REDEF | RE_WARNING, szName, "* Ignoring");    
+  }
 
   pibIn->iLNPrev = pibIn->iLineNum; /* Update prev eqn line num */
 
@@ -477,7 +487,7 @@ void DefineScaleEqn (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, HANDLE hType)
 /* ----------------------------------------------------------------------------
    DefineCalcOutEqn
    
-   Defines an equation in the pvmCalcOutEqn list.  Only outputs
+   Defines an equation in the pvmCalcOutEqn list. Only outputs
    can be redefined here.
 */
 void DefineCalcOutEqn (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, HANDLE hType)
@@ -487,19 +497,24 @@ void DefineCalcOutEqn (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, HANDLE hType)
 
   /* If there was more than one line since last equation, set ID_SPACEFLAG.  
      This is kind of a kludge so I can use PVMMAPSTRCT struct. */
-
   if (pibIn->iLineNum - pibIn->iLNPrev - 1)
     hNewType |= ID_SPACEFLAG;
 
-  if (!hType) /* Original type is NULL */
-    AddEquation (&pinfo->pvmGloVars, szName, NULL, hNewType);
+  if (!strcmp (szName, "Inline")) /* Inline statements are accumulated */
+    AddEquation (&pinfo->pvmCalcOutEqns, szName, szEqn, ID_INLINE);
+
+  else {
+
+    if (!hType) /* Original type is NULL */
+      AddEquation (&pinfo->pvmGloVars, szName, NULL, hNewType);
     
-  if ((hType & ID_LOCALCALCOUT) /* Many per local */
-      || !GetVarPTR (pinfo->pvmCalcOutEqns, szName)) /* 1 eqn per parm */
-    AddEquation (&pinfo->pvmCalcOutEqns, szName, szEqn, hNewType);
+    if ((hType & ID_LOCALCALCOUT) || /* Many per local */
+        !GetVarPTR (pinfo->pvmCalcOutEqns, szName)) /* 1 eqn per parm */
+      AddEquation (&pinfo->pvmCalcOutEqns, szName, szEqn, hNewType);
     
-  else
-    ReportError (pibIn, RE_REDEF | RE_WARNING, szName, "* Ignoring");    
+    else
+      ReportError (pibIn, RE_REDEF | RE_WARNING, szName, "* Ignoring");    
+  }
 
   pibIn->iLNPrev = pibIn->iLineNum; /* Update prev eqn line num */
 
@@ -576,8 +591,9 @@ void DefineVariable (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, int iKWCode)
     hGloVarType = TYPE(pvm);
   }
 
-  if ((hGloVarType != ID_INPUT || pinfo->wContext != CN_GLOBAL)
-      && !VerifyEqn (pibIn, szEqn))
+  if ((iKWCode != KM_INLINE) &&
+      (hGloVarType != ID_INPUT || pinfo->wContext != CN_GLOBAL) &&
+      !VerifyEqn (pibIn, szEqn))
     return; /* Errors reported in Verify eqn */
 
   switch (pinfo->wContext) {
@@ -606,8 +622,11 @@ void DefineVariable (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, int iKWCode)
       break;
 
     case CN_CALCOUTPUTS: /* FB added ID_NULL and RE_FATAL, 1 mar 98 */
-      /* only outputs and local variables can be assigned in CalcOutputs */
-      if ((hGloVarType == ID_OUTPUT) || (hGloVarType == ID_NULL))
+      /* only outputs, local variables, and inlines can be assigned in 
+         CalcOutputs */
+      if ((hGloVarType == ID_OUTPUT) || 
+          (hGloVarType == ID_NULL) ||
+          (iKWCode == KM_INLINE))
         DefineCalcOutEqn (pibIn, szName, szEqn, hGloVarType);
       else
         ReportError (pibIn, RE_BADCONTEXT  | RE_FATAL, szName,
