@@ -128,12 +128,12 @@ int CountOneDecl (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 int WriteOneName (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 {
   if (pvm->szEqn != vszHasInitializer) { /* These appear later */
-    fprintf (pfile, "      %s", pvm->szName);
+    fprintf (pfile, "     %s", pvm->szName);
     if (TYPE(pvm) != ID_INPUT)
-      fprintf (pfile, " \t%s %s\n", (pvm->szEqn ? ":=" : "->"),
+      fprintf (pfile, " %s %s\n", (pvm->szEqn ? ":=" : "->"),
                (pvm->szEqn ? pvm->szEqn : "0.0"));
     else
-      fprintf (pfile, " is an input function\n");
+      fprintf (pfile, " (is a function)\n");
 
     return (1);
   } /* if */
@@ -168,18 +168,22 @@ void WriteHeader (PFILE pfile, PSTR szName, PVMMAPSTRCT pvmGlo)
 
   fprintf (pfile, "   " VSZ_COPYRIGHT "\n");
 
-  fprintf (pfile, "\n  Model calculations for compartmental model:\n\n");
+  fprintf (pfile, "\n   Model calculations for compartmental model:\n\n");
 
-  fprintf (pfile, "    %d States:\n", vnStates);
+  if (vnStates == 1) fprintf (pfile, "   1 State:\n");
+  else fprintf (pfile, "   %d States:\n", vnStates);
   ForAllVar (pfile, pvmGlo, &WriteOneName, ID_STATE, NULL);
 
-  fprintf (pfile, "\n    %d Outputs:\n", vnOutputs);
+  if (vnOutputs == 1) fprintf (pfile, "\n   1 Output:\n");
+  else fprintf (pfile, "\n   %d Outputs:\n", vnOutputs);
   ForAllVar (pfile, pvmGlo, &WriteOneName, ID_OUTPUT, NULL);
     
-  fprintf (pfile, "\n    %d Inputs:\n", vnInputs);
+  if (vnInputs == 1) fprintf (pfile, "\n   1 Input:\n");
+  else fprintf (pfile, "\n   %d Inputs:\n", vnInputs);
   ForAllVar (pfile, pvmGlo, &WriteOneName, ID_INPUT, NULL);
 
-  fprintf (pfile, "\n    %d Parameters:\n", vnParms);
+  if (vnParms == 1) fprintf (pfile, "\n   1 Parameter:\n");
+  else fprintf (pfile, "\n   %d Parameters:\n", vnParms);
   ForAllVar (pfile, pvmGlo, &WriteOneName, ID_PARM, NULL);
   
   fprintf (pfile, "*/\n\n");
@@ -215,11 +219,10 @@ int WriteOneDecl (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
   assert(TYPE(pvm) != ID_OUTPUT);
   assert(TYPE(pvm) != ID_STATE);
 
-  if (TYPE(pvm) & (ID_LOCALDYN | ID_LOCALSCALE | ID_LOCALJACOB | 
-                   ID_LOCALCALCOUT))
-    fprintf (pfile, "  ");
+  if (TYPE(pvm) > ID_PARM) fprintf (pfile, "  /* local */ ");
 
   fprintf (pfile, "double %s;\n", pvm->szName);
+
   return (1);
 
 } /* WriteOneDecl */
@@ -233,9 +236,9 @@ int WriteOneIndexDefine (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
     fprintf (pfile, "#define ");
     WriteIndexName(pfile, pvm);
     if (INDEX(pvm))
-      fprintf (pfile, "\t0x%04x\n", INDEX(pvm));
+      fprintf (pfile, " 0x%04x\n", INDEX(pvm));
     else
-      fprintf (pfile, "\t0x0000\n");
+      fprintf (pfile, " 0x0000\n");
 
     return 1;
   }  /* if */
@@ -249,7 +252,7 @@ int WriteOneIndexDefine (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 */
 void WriteDecls (PFILE pfile, PVMMAPSTRCT pvmGlo)
 {
-  fprintf (pfile, "\n/*----- Indices to Global Variables */\n");
+  fprintf (pfile, "\n\n/*----- Indices to Global Variables */\n");
 
   fprintf (pfile, "\n/* Model variables: States and other outputs */\n");
   ForAllVar (pfile, pvmGlo, &WriteOneIndexDefine, ID_STATE, NULL);
@@ -260,28 +263,28 @@ void WriteDecls (PFILE pfile, PVMMAPSTRCT pvmGlo)
   fprintf (pfile, "\n/* Parameters */\n");
   ForAllVar (pfile, pvmGlo, &WriteOneIndexDefine, ID_PARM, NULL);
   
-  fprintf (pfile, "\n/*----- Global Variables */\n");
+  fprintf (pfile, "\n\n/*----- Global Variables */\n");
 
-  fprintf (pfile, "\n  /* For export.  Keep track of who we are. */\n");
+  fprintf (pfile, "\n/* For export. Keep track of who we are. */\n");
   fprintf (pfile, "char szModelDescFilename[] = \"%s\";\n", vszModelFilename);
   fprintf (pfile, "char szModelSourceFilename[] = __FILE__;\n");
   fprintf (pfile, "char szModelGenAndVersion[] = \"%s %s\";\n",
     vszModGenName, VSZ_VERSION);
 
-  fprintf (pfile, "\n  /* Externs */\n");
+  fprintf (pfile, "\n/* Externs */\n");
   fprintf (pfile, "extern BOOL vbModelReinitd;\n");
 
-  fprintf (pfile, "\n  /* Model Dimensions */\n");
-  fprintf (pfile, "int vnStates\t= %d;\n", vnStates);
-  fprintf (pfile, "int vnOutputs\t= %d;\n", vnOutputs);
-  fprintf (pfile, "int vnModelVars\t= %d;\n", vnModelVars);
-  fprintf (pfile, "int vnInputs\t= %d;\n", vnInputs);
-  fprintf (pfile, "int vnParms\t= %d;\n", vnParms);
+  fprintf (pfile, "\n/* Model Dimensions */\n");
+  fprintf (pfile, "int vnStates = %d;\n", vnStates);
+  fprintf (pfile, "int vnOutputs = %d;\n", vnOutputs);
+  fprintf (pfile, "int vnModelVars = %d;\n", vnModelVars);
+  fprintf (pfile, "int vnInputs = %d;\n", vnInputs);
+  fprintf (pfile, "int vnParms = %d;\n", vnParms);
 
-  fprintf (pfile, "\n  /* States and Outputs*/\n");
+  fprintf (pfile, "\n/* States and Outputs*/\n");
   fprintf (pfile, "double %s[%d];\n", vszModelArrayName, vnModelVars);
 
-  fprintf (pfile, "\n  /* Inputs */\n");
+  fprintf (pfile, "\n/* Inputs */\n");
   /* if vnInputs is zero put a dummy 1 for array size */
   fprintf (pfile, "IFN %s[%d];\n", vszInputArrayName, 
            (vnInputs > 0 ? vnInputs : 1));
@@ -351,7 +354,7 @@ int WriteOneVMEntry (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
   int iType = TYPE(pvm);
 
   if (!pvm) {
-    fprintf (pfile, "    {\"\",\tNULL,\t0} /* End flag */\n");
+    fprintf (pfile, "  {\"\", NULL, 0} /* End flag */\n");
     return 0;
   }
     
@@ -359,10 +362,10 @@ int WriteOneVMEntry (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
     iType != ID_LOCALDYN && iType != ID_LOCALSCALE && iType != ID_LOCALJACOB);
 
   if (pvm->szEqn != vszHasInitializer) { /* These appear later */
-    fprintf (pfile, "    {\"%s\",\t(PVOID) &%s", pvm->szName,
+    fprintf (pfile, "  {\"%s\", (PVOID) &%s", pvm->szName,
              GetName(pvm, vszModelArrayName, NULL, ID_NULL));
     
-    fprintf (pfile, ", \tID_%s | ID_%s},\n", 
+    fprintf (pfile, ", ID_%s | ID_%s},\n", 
              (iType == ID_PARM ? "PARM"
               : (iType == ID_INPUT ? "INPUT"
               : (iType == ID_OUTPUT ? "OUTPUT"
@@ -381,17 +384,11 @@ int WriteOneVMEntry (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 */
 void WriteVarMap (PFILE pfile, PVMMAPSTRCT pvmGlo)
 {
-  fprintf (pfile, "\n\n/*----- Global Variable Map */\n");
+  fprintf (pfile, "\n\n/*----- Global Variable Map */\n\n");
   fprintf (pfile, "VMMAPSTRCT vrgvmGlo[] = {\n");
   ForAllVar (pfile, pvmGlo, &WriteOneVMEntry, ID_STATE, NULL);  
-  fprintf (pfile, "\n");
-
   ForAllVar (pfile, pvmGlo, &WriteOneVMEntry, ID_OUTPUT, NULL);
-  fprintf (pfile, "\n");
-
   ForAllVar (pfile, pvmGlo, &WriteOneVMEntry, ID_INPUT, NULL);
-  fprintf (pfile, "\n");
-
   ForAllVar (pfile, pvmGlo, &WriteOneVMEntry, ID_PARM, NULL);
   WriteOneVMEntry (pfile, NULL, NULL); /* Include end flag */
   fprintf (pfile, "};  /* vrgpvmGlo[] */\n");
@@ -406,8 +403,9 @@ int WriteOneInit (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
   IFN ifnNull = {IFN_CONSTANT}; /* Init other fields to zero */
   PSTR szVarName = GetName (pvm, NULL, NULL, ID_NULL);
 
-  if (pvm->szEqn != vszHasInitializer /* These appear later */
-      && TYPE(pvm) <= ID_PARM) { /* No Locals!  */
+  if ((pvm->szEqn != vszHasInitializer && /* These appear later */
+       TYPE(pvm) <= ID_PARM) || /* No Locals!  */
+      (TYPE(pvm) == ID_INLINE)) { 
     
     if (TYPE(pvm) == ID_INPUT) {
       PIFN pifn = (PIFN) pvm->szEqn;
@@ -415,30 +413,35 @@ int WriteOneInit (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
       if (!pifn) /* No eqn, init to zero */
         pifn = &ifnNull;
       
-      fprintf (pfile, "\n  %s.iType = %s;\n",
+      fprintf (pfile, "  %s.iType = %s;\n",
                szVarName, vszIFNTypes[pifn->iType]);
       fprintf (pfile, "  %s.dTStartPeriod = 0.0;\n", szVarName);
-      fprintf (pfile, "  %s.bOn  = FALSE;\n", szVarName);
+      fprintf (pfile, "  %s.bOn = FALSE;\n", szVarName);
       fprintf (pfile, "  %s.dMag = %f;\n", szVarName, pifn->dMag);
-      fprintf (pfile, "  %s.dT0  = %f;\n", szVarName, pifn->dT0);
+      fprintf (pfile, "  %s.dT0 = %f;\n", szVarName, pifn->dT0);
       fprintf (pfile, "  %s.dTexp = %f;\n", szVarName, pifn->dTexp);
-      fprintf (pfile, "  %s.dDecay  = %f;\n", szVarName, pifn->dDecay);
+      fprintf (pfile, "  %s.dDecay = %f;\n", szVarName, pifn->dDecay);
       fprintf (pfile, "  %s.dTper = %f;\n", szVarName, pifn->dTper);
       
       fprintf (pfile, "  %s.hMag = %#x;\n", szVarName, pifn->hMag);
-      fprintf (pfile, "  %s.hT0  = %#x;\n", szVarName, pifn->hT0);
+      fprintf (pfile, "  %s.hT0 = %#x;\n", szVarName, pifn->hT0);
       fprintf (pfile, "  %s.hTexp = %#x;\n", szVarName, pifn->hTexp);
-      fprintf (pfile, "  %s.hDecay  = %#x;\n", szVarName, pifn->hDecay);
+      fprintf (pfile, "  %s.hDecay = %#x;\n", szVarName, pifn->hDecay);
       fprintf (pfile, "  %s.hTper = %#x;\n", szVarName, pifn->hTper);
       
-      fprintf (pfile, "  %s.dVal  = 0.0;\n", szVarName);
+      fprintf (pfile, "  %s.dVal = 0.0;\n", szVarName);
       fprintf (pfile, "  %s.nDoses = 0;\n", szVarName);
     } /* if */
-    else 
-      fprintf (pfile, "  %s = %s;\n", szVarName,
-               (pvm->szEqn ? pvm->szEqn : "0.0"));
+    else {
+      if (TYPE(pvm) == ID_INLINE) /* write out just the equation */
+        fprintf (pfile, "  %s\n", pvm->szEqn);
+      else
+        fprintf (pfile, "  %s = %s;\n", szVarName,
+                 (pvm->szEqn ? pvm->szEqn : "0.0"));
+    } /* else */
 
     return (1);
+
   } /* if */
 
   return (0);
@@ -453,47 +456,21 @@ int WriteOneInit (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 */
 void WriteInitModel (PFILE pfile, PVMMAPSTRCT pvmGlo)
 {
-  fprintf (pfile, "\n/* InitModel\n\n");
+  fprintf (pfile, "\n\n/*----- InitModel\n");
   fprintf (pfile, "   Should be called to initialize model variables at\n");
   fprintf (pfile, "   the beginning of experiment before reading\n");
   fprintf (pfile, "   variants from the simulation spec file.\n*/\n\n");
   fprintf (pfile, "void InitModel(void)\n{\n");
-  fprintf (pfile, "/*-- Initialize things in the order that they appear in\n"
+  fprintf (pfile, "  /* Initialize things in the order that they appear in\n"
       "     model definition file so that dependencies are\n"
       "     handled correctly. */\n\n");
   ForAllVar (pfile, pvmGlo, &WriteOneInit, ALL_VARS, NULL);
-  fprintf (pfile, "\n  vbModelReinitd = TRUE;  /* Flag is initialized */\n");
-  fprintf (pfile, "} /* InitModel */\n\n");
+  fprintf (pfile, "\n  vbModelReinitd = TRUE;\n\n");
+  fprintf (pfile, "} /* InitModel */\n\n\n");
 
 } /* WriteInitModel */
 
 
-#ifdef ndef
-/* ----------------------------------------------------------------------------
-   WriteInitExpt
-   
-   Writes the routine to initialize certain model variables.
-*/
-
-void WriteInitExpt (PFILE pfile, PVMMAPSTRCT pvmGlo)
-{
-  fprintf (pfile, "\n/* InitExpt\n\n");
-  fprintf (pfile, "   Should be called to initialize model variables at\n");
-  fprintf (pfile, "   the beginning of experiment after reading\n");
-  fprintf (pfile, "   variants from the simulation spec file.\n*/\n\n");
-  fprintf (pfile, "void InitExpt()\n{\n");
-  fprintf (pfile, "/*-- Initialize things in the order that they appear in\n"
-      "     model definition file so that dependencies are\n"
-      "     handled correctly. */\n\n");
-  ForAllVar (pfile, pvmGlo, &WriteOneInit, ID_STATE, NULL);
-  ForAllVar (pfile, pvmGlo, &WriteOneInit, ID_INPUT, NULL);
-  ForAllVar (pfile, pvmGlo, &WriteOneInit, ID_OUTPUT, NULL);
-  fprintf (pfile, "\n  vbModelReinitd = TRUE;  /* Flag is initialized */\n");
-  fprintf (pfile, "} /* InitExpt */\n\n");
-} /* WriteInitExpt */
-#endif
-
-
 /* ----------------------------------------------------------------------------
    TranslateID
    
@@ -638,19 +615,25 @@ int WriteOneEquation (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
         exit(0);
       }
 
-      fprintf (pfile, "  %s = ", GetName (pvm, NULL, NULL, ID_NULL));
+      if (TYPE(pvm) != ID_INLINE) /* do not write "Inline" */
+        fprintf (pfile, "  %s = ", GetName (pvm, NULL, NULL, ID_NULL));
       break;
 
     case KM_CALCOUTPUTS:
     case KM_DYNAMICS:
     case KM_JACOB:
-      fprintf (pfile, "  %s = ", GetName (pvm, "rgModelVars", "rgDerivs", 
-               ID_NULL));
+      if (TYPE(pvm) != ID_INLINE) /* do not write "Inline" */
+        fprintf (pfile, "  %s = ", GetName (pvm, "rgModelVars", "rgDerivs", 
+                 ID_NULL));
       break;
 
   } /* switch */
 
-  TranslateEquation (pfile, pvm->szEqn, iType);
+  if (TYPE(pvm) == ID_INLINE) /* write out the equation */
+    fprintf (pfile, "\n  %s\n", pvm->szEqn);
+  else
+    TranslateEquation (pfile, pvm->szEqn, iType);
+
   return 1;
 
 } /* WriteOneEquation */
@@ -666,17 +649,15 @@ int WriteOneEquation (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 void WriteCalcDeriv (PFILE pfile, PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmDyn)
 {
   if (!pvmDyn)
-    printf ("No Dynamics{} equations.\n");
+    printf ("No Dynamics{} equations.\n\n");
 
-  fprintf (pfile, "/* Dynamics section */\n");
+  fprintf (pfile, "/*----- Dynamics section */\n\n");
   fprintf (pfile, "void CalcDeriv (double  rgModelVars[], ");
   fprintf (pfile, "double  rgDerivs[], PDOUBLE pdTime)\n{\n");
-  fprintf (pfile, "  /* Local variables */\n");
 
   ForAllVar (pfile, pvmGlo, &WriteOneDecl, ID_LOCALDYN, NULL);
 
-  fprintf (pfile, "\n");
-  fprintf (pfile, "  CalcInputs (pdTime);  /* Get new input vals */\n");
+  fprintf (pfile, "\n  CalcInputs (pdTime); /* Get new input vals */\n");
 
   ForAllVar (pfile, pvmDyn, &WriteOneEquation, ALL_VARS, (PVOID) KM_DYNAMICS); 
  
@@ -692,12 +673,11 @@ void WriteCalcDeriv (PFILE pfile, PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmDyn)
 void WriteScale (PFILE pfile, PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmScale)
 {
   if (!pvmScale)
-    printf ("No Scale{} equations. Null function defined.\n");
+    printf ("No Scale{} equations. Null function defined.\n\n");
     
-  fprintf (pfile, "/* Model scaling */\n");
+  fprintf (pfile, "/*----- Model scaling */\n\n");
   fprintf (pfile, "void ScaleModel (void)\n");
   fprintf (pfile, "{\n");
-  fprintf (pfile, "  /* Local variables */\n");
   ForAllVar (pfile, pvmGlo, &WriteOneDecl, ID_LOCALSCALE, NULL);
   ForAllVar (pfile, pvmScale, &WriteOneEquation, ALL_VARS, (PVOID) KM_SCALE);  
   fprintf (pfile, "\n} /* ScaleModel */\n\n\n");
@@ -710,11 +690,13 @@ void WriteScale (PFILE pfile, PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmScale)
 */
 void WriteCalcJacob (PFILE pfile, PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmJacob)
 {
-  fprintf (pfile, "/* Jacobian calculation */\n");
+  /*  if (!pvmJacob)
+      printf ("No Jacobian{} equations. Null function defined.\n\n"); */
+
+  fprintf (pfile, "/*----- Jacobian calculations */\n\n");
   fprintf (pfile, "void CalcJacob (double rgModelVars[], double *rgdSave[]");
   fprintf (pfile, ", PDOUBLE pdTime)\n");
   fprintf (pfile, "{\n");
-  fprintf (pfile, "  /* Local variables */\n");
   ForAllVar (pfile, pvmGlo, &WriteOneDecl, ID_LOCALJACOB, NULL);
   ForAllVar (pfile, pvmJacob, &WriteOneEquation, ALL_VARS, (PVOID) KM_JACOB);  
   fprintf (pfile, "\n} /* CalcJacob */\n\n\n");
@@ -727,12 +709,11 @@ void WriteCalcJacob (PFILE pfile, PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmJacob)
 void WriteCalcOutputs (PFILE pfile, PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmCalcOut)
 {
   if (!pvmCalcOut)
-    printf ("No CalcOutput{} equations. Null function defined.\n");
+    printf ("No CalcOutput{} equations. Null function defined.\n\n");
     
-  fprintf (pfile, "/* Outputs calculation */\n");
+  fprintf (pfile, "/*----- Outputs calculations */\n\n");
   fprintf (pfile, "void CalcOutputs (double  rgModelVars[], ");
   fprintf (pfile, "double  rgDerivs[], PDOUBLE pdTime)\n{\n");
-  fprintf (pfile, "  /* Local variables */\n");
   ForAllVar (pfile, pvmGlo, &WriteOneDecl, ID_LOCALCALCOUT, NULL);
   ForAllVar (pfile, pvmCalcOut, &WriteOneEquation, ALL_VARS, 
              (PVOID) KM_CALCOUTPUTS); 
@@ -1024,7 +1005,6 @@ void WriteModel (PINPUTINFO pinfo, int nArg, PSTR rgszArgs[])
     WriteVarMap (pfile, pinfo->pvmGloVars);
 
     WriteInitModel (pfile, pinfo->pvmGloVars);
-/*  WriteInitExpt (pfile, pinfo->pvmGloVars); FB 7/12/96 commented out */
     WriteCalcDeriv (pfile, pinfo->pvmGloVars, pinfo->pvmDynEqns);
     WriteScale (pfile, pinfo->pvmGloVars, pinfo->pvmScaleEqns);
     WriteCalcJacob (pfile, pinfo->pvmGloVars, pinfo->pvmJacobEqns);
