@@ -5,11 +5,25 @@
    
    Copyright (c) 1993.  Don Maszle, Frederic Bois.  All rights reserved.
 
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
    -- Revisions -----
-     Logfile:  SCCS/s.strutil.c
-    Revision:  1.3
-        Date:  20 Dec 1994
-     Modtime:  03:22:54
+     Logfile:  %F%
+    Revision:  %I%
+        Date:  %G%
+     Modtime:  %U%
       Author:  @a
    -- SCCS  ---------
 
@@ -30,6 +44,8 @@
 
 #include "strutil.h"
 
+/* ---------------------------------------------------------------------------
+*/
 int MyStrcmp(const char* sz1, const char* sz2)
 {
   if (!sz1) {
@@ -53,3 +69,5 @@ int MyStrcmp(const char* sz1, const char* sz2)
 
 
 /* End */
+
+
