@@ -3,7 +3,7 @@
    written by Don Maszle
    10 October 1991
 
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1991-2004.  Don Maszle, Frederic Bois.  All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -19,19 +19,11 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-   contact
-     Frdric Bois / Don Maszle
-     BEHS, School of Public Health
-     University of California at Berkeley
-     Berkeley, CA 94720
-
-     fbois@diana.lbl.gov
-
    -- Revisions -----
-     Logfile:  SCCS/s.lex.c
-    Revision:  1.14
-        Date:  29 Jul 1997
-     Modtime:  08:08:44
+     Logfile:  %F%
+    Revision:  %I%
+        Date:  %G%
+     Modtime:  %U%
       Author:  @a
    -- SCCS  ---------
 
@@ -95,7 +87,7 @@ PSTR vrgszLexTypes[] = {
 
 void PreventLexSplit (PINPUTBUF pibIn, int iOffset)
 {
-  long lFilePos, lDelta;
+  long lDelta;
   PBUF pbufEOB = pibIn->pbufOrg + iOffset;
   PBUF pbufEOBOld;
 
@@ -103,7 +95,6 @@ void PreventLexSplit (PINPUTBUF pibIn, int iOffset)
       || (iOffset == BUFFER_SIZE)) {    /* No room for NULL */
 
     pbufEOBOld = pbufEOB;        /* Save EOB */
-    lFilePos = ftell (pibIn->pfileIn);    /* Save position */
     while (*(--pbufEOB) != CH_EOLN)
       ;                /* Move EOB to last EOLN */
     *pbufEOB = '\0';        /* Overwrite EOLN with NULL */
@@ -343,7 +334,6 @@ void GetIdentifier (PINPUTBUF pibIn, PSTR szLex)
 
 void GetNumber (PINPUTBUF pibIn, PSTR szLex, PINT piLexType)
 {
-  PBUF pbufCur;
   int i = 0;
   char c;
   BOOL bHasSign = FALSE;
@@ -354,7 +344,6 @@ void GetNumber (PINPUTBUF pibIn, PSTR szLex, PINT piLexType)
   if (!pibIn || !szLex || !piLexType)
     return;
 
-  pbufCur = pibIn->pbufCur;
   eState = Start;
   *piLexType = LX_NULL;
   while ((c = *pibIn->pbufCur)
@@ -667,7 +656,6 @@ void EatStatement (PINPUTBUF pib)
 
 void GetStatement (PINPUTBUF pibIn, PSTR szStmt)
 {
-  char c;
   int i, fDone = 0;
 
   if (!pibIn || !szStmt)
@@ -677,19 +665,21 @@ void GetStatement (PINPUTBUF pibIn, PSTR szStmt)
 
   i = 0;
   if (!EOB(pibIn)) {
-    c = *pibIn->pbufCur;
     while (!fDone) {
       if (*pibIn->pbufCur) {
-        if (!(fDone = (NextChar (pibIn) == CH_STMTTERM)))
+        if (!(fDone = (NextChar (pibIn) == CH_STMTTERM))) {
           if (i < MAX_EQN-2) {
             if ((szStmt[i++] = *pibIn->pbufCur++) == CH_EOLN)
               pibIn->iLineNum++;
           } /* if */
-          else
+          else {
             ReportError (pibIn, RE_EQNTOOLONG | RE_FATAL, NULL, NULL);
+          }
+        } /* if !fDone... */
       } /* if pibIn->pbufCur */
-      else
-      fDone = (FillBuffer (pibIn) == EOF);
+      else {
+        fDone = (FillBuffer (pibIn) == EOF);
+      }
     } /* while */
 
     szStmt[i] = '\0';
@@ -766,8 +756,8 @@ BOOL GetFuncArgs (PINPUTBUF pibIn,
     if (i)
       if (!(bOK = GetOptPunct (pibIn, szArgs, ','))) {
         *(szArgs+1) = ',';
-        ReportError(pibIn, RE_EXPECTED, szArgs, NULL);
-        break;                /* Error: Stop getting args */
+        ReportError (pibIn, RE_EXPECTED, szArgs, NULL);
+        break; /* Error: Stop getting args */
       }
 
     NextLex (pibIn, szArgs, &iType);
