@@ -3,7 +3,7 @@
    written by D.R.Maszle
    28 October 1991
 
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1991-2004.  Don Maszle, Frederic Bois.  All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -19,19 +19,11 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-   contact
-     Frdric Bois / Don Maszle
-     BEHS, School of Public Health
-     University of California at Berkeley
-     Berkeley, CA 94720
-
-     fbois@diana.lbl.gov
-
    -- Revisions -----
-     Logfile:  SCCS/s.list.c
-    Revision:  1.13
-        Date:  14 Nov 1997
-     Modtime:  06:38:58
+     Logfile:  %F%
+    Revision:  %I%
+        Date:  %G%
+     Modtime:  %U%
       Author:  @a
    -- SCCS  ---------
 
@@ -51,7 +43,7 @@
    LIST may then be used in other exciting list functions.
 */
 
-PLIST InitList ()
+PLIST InitList (void)
 {
   /* Allocate header record */
   PLIST plist = (PLIST) malloc (sizeof(LIST));
