@@ -1497,16 +1497,24 @@ int PrintExpt (PLEVEL plevel, char **args)
             fprintf (pOutFile, "%d\t%s\t%g\t\t%g\n", pExpt->iExp,
                      pos->pszOutputNames[m], pos->prgdOutputTimes[m][l],
                      pos->prgdOutputVals[m][l]);
-        }
-      }
-    }
 
-  } /* if */
+        } /* end for l */
+
+        fprintf (pOutFile, "\n");
+
+      } /* end for m */
+
+      fprintf (pOutFile, "\n");
+
+    } /* end else */
+
+  } /* end if pExpt */
 
   return (1);
 
 } /* PrintExpt*/
 
+
 /* Function -------------------------------------------------------------------
    ReadData
 
@@ -1886,14 +1894,14 @@ long SampleTemperature (long indexT, double dLnPrior, double dLnData,
 double SampleTheta (PMCVAR pMCVar) {
 
   /* if the parameter has a discrete distribution, round it - FB 12/06/97 */
-  if (pMCVar->iType == MCV_BINOMIAL || pMCVar->iType == MCV_POISSON ) {
+  if (pMCVar->iType == MCV_BINOMIAL || pMCVar->iType == MCV_POISSON) {
    return floor (0.5 + TruncNormalRandom (pMCVar->dVal, pMCVar->dKernelSD,
                                           MinMCVar(pMCVar),
                                           MaxMCVar(pMCVar)));
   }
   else { /* FB fixed the uniform case - FB 30/06/97 */
     return TruncNormalRandom (pMCVar->dVal, pMCVar->dKernelSD,
-                              MinMCVar(pMCVar), MaxMCVar(pMCVar) );
+                              MinMCVar(pMCVar), MaxMCVar(pMCVar));
   }
 
 } /* SampleTheta */
