@@ -149,22 +149,23 @@ void FixupDependentInputs (void)
         vrgInputs[i].dTexp = vrgInputs[i].dTper;
     }
 
-    /* FB 9/9/97: Assure that input does not exceed the period */
-    if (vrgInputs[i].dTexp != 0.0
-        && vrgInputs[i].dT0 + vrgInputs[i].dTexp >= vrgInputs[i].dTper)
-      vrgInputs[i].dTexp = vrgInputs[i].dTper - vrgInputs[i].dT0 /* - 1e-6 */;
+    /* FB 9/9/97, modified 29/5/2006: make sure that the exposure does not 
+       exceed the period */
+    if (vrgInputs[i].dTexp >= vrgInputs[i].dTper)
+      vrgInputs[i].dTexp = vrgInputs[i].dTper;
 
     /* For doses and spikes allow scaling in Scale{} by use of dMag */
     if (vrgInputs[i].iType == IFN_NDOSES || vrgInputs[i].iType == IFN_SPIKES)
       vrgInputs[i].dMag = 1.0; /* Initially no scaling */
 
+    /* FB 29/5/2006 removed a condition leading to failure if the start time
+       was superior to the period */
     /* If the input is ill-defined, turn it off */
-    if (vrgInputs[i].iType != IFN_NDOSES && vrgInputs[i].iType != IFN_CONSTANT
-        && vrgInputs[i].iType != IFN_SPIKES) {
-      if (vrgInputs[i].dTexp == 0.0
-          || vrgInputs[i].dT0 > vrgInputs[i].dTper
-          || vrgInputs[i].dT0 < 0.0
-          || vrgInputs[i].dTper < 0.0 )
+    if (vrgInputs[i].iType == IFN_PERDOSE || 
+        vrgInputs[i].iType == IFN_PEREXP) {
+      if (vrgInputs[i].dTexp == 0.0 || 
+          vrgInputs[i].dT0 < 0.0 || 
+          vrgInputs[i].dTper < 0.0)
         vrgInputs[i].dMag = 0.0;
     } /* if */
 
