@@ -129,7 +129,7 @@ int CalculateOneMCParm (PMCVAR pMCVar)
       break;
 
     case MCV_HALFNORMAL:
-      pMCVar->dVal = abs(NormalRandom (dParm1, dParm2));
+      pMCVar->dVal = fabs(NormalRandom (dParm1, dParm2));
       break;
 
     case MCV_LOGNORMAL:
