@@ -2,7 +2,7 @@
 
    originally written by Frederic Bois
 
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.  All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -18,26 +18,18 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-   contact
-     Frdric Bois / Don Maszle
-     BEHS, School of Public Health
-     University of California at Berkeley
-     Berkeley, CA 94720
-
-     fbois@diana.lbl.gov
-
    -- Revisions -----
-     Logfile:  SCCS/s.simmonte.h
-    Revision:  1.12
-        Date:  14 Nov 1997
-     Modtime:  06:39:21
+     Logfile:  %F%
+    Revision:  %I%
+        Date:  %G%
+     Modtime:  %U%
       Author:  @a
    -- SCCS  ---------
 
    Header file for simmonte.c
 */
 
-/* -----------------------------------------------------------------------------
+/* ----------------------------------------------------------------------------
    Prototypes */
 
 void CalcMCParms (PMONTECARLO pMC, double rgParms[], long iStart);
@@ -49,6 +41,7 @@ BOOL ReadSetPoints (PMONTECARLO pMC, double rgParms[]);
 void SetParents (PMONTECARLO pMC, long iStart);
 void SetParms (long cParms, HVAR *rghvar, double *rgdParm);
 void SetParmsLog (long cParms, HVAR *rghvar, double *rgdParm);
+void SetParmsExp (long cParms, HVAR *rghvar, double *rgdParm);
 
 /* End */
 
