@@ -2,7 +2,7 @@
 
    written by Frederic Bois
    
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.  All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -18,19 +18,11 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-   contact
-     Frdric Bois / Don Maszle
-     BEHS, School of Public Health
-     University of California at Berkeley
-     Berkeley, CA 94720
-
-     fbois@diana.lbl.gov
-
    -- Revisions -----
-     Logfile:  SCCS/s.yourcode.c
-    Revision:  1.19
-        Date:  14 Nov 1997
-     Modtime:  06:39:11
+     Logfile:  %F%
+    Revision:  %I%
+        Date:  %G%
+     Modtime:  %U%
       Author:  @a
    -- SCCS  ---------
 
@@ -38,11 +30,6 @@
    
 */
 
-#ifdef _MACOSLEVEL2_
-#include <PPC Macheaders>
-#include "mac.h"
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -53,7 +40,7 @@
 #include "yourcode.h"
 
 
-/* ----------------------------------------------------------------------------
+/* ---------------------------------------------------------------------------
    DoStep_by_Step 
    
    routine called after each successful step of the integrator. 
@@ -84,7 +71,7 @@ void DoStep_by_Step (/* double t, long *neq, double *y */)
 } /* DoStep_by_Step */
 
 
-/* ----------------------------------------------------------------------------
+/* ---------------------------------------------------------------------------
    TransformPred
 
    At least flattens the model predictions in a simple array after a 
@@ -111,7 +98,7 @@ void TransformPred (PANALYSIS panal, PMCPREDOUT pMCPredOut)
 } /* TransformPred */
 
 
-/* ----------------------------------------------------------------------------
+/* ---------------------------------------------------------------------------
    OutspecToLinearArray
 
    Flattens the panal nested output arrays on a single array.
@@ -146,12 +133,12 @@ void OutspecToLinearArray (PANALYSIS panal, PMCPREDOUT pMCPredOut)
   for (i = 0; i < panal->expGlobal.iExp; i++)
     for (j = 0, pos = &panal->rgpExps[i]->os; j < pos->nOutputs; j++)
       for (k = 0; k < pos->pcOutputTimes[j]; k++)
-      pMCPredOut->pred[pMCPredOut->nbrdy++] = pos->prgdOutputVals[j][k];
+        pMCPredOut->pred[pMCPredOut->nbrdy++] = pos->prgdOutputVals[j][k];
 
 } /* OutspecToLinearArray */
 
 
-/* ----------------------------------------------------------------------------
+/* ---------------------------------------------------------------------------
    Definite_Integral
 
    Performs the integration of an analytic function using Rhomberg algorithm.
@@ -217,7 +204,7 @@ double Definite_Integral (double (*Function)(double), double dFrom, double dTo)
 } /* Definite_Integral */
 
 
-/* ----------------------------------------------------------------------------
+/* ---------------------------------------------------------------------------
    Interpolate_Poly
 
    Adapted from the algorithm described in the book Numerical Recipes by
@@ -276,7 +263,7 @@ void Interpolate_Poly (double rgdX[], double rgdY[], int n, double x,
 } /* Interpolate_Poly */
 
 
-/* ----------------------------------------------------------------------------
+/* ---------------------------------------------------------------------------
    Trapezes
 
    Integrates an analytic function using the trapeze method. This is called
