@@ -2,7 +2,7 @@
 
    written by Frederic Bois
    
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.  All rights reserved.
+   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.  All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -18,19 +18,11 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-   contact
-     Frdric Bois / Don Maszle
-     BEHS, School of Public Health
-     University of California at Berkeley
-     Berkeley, CA 94720
-
-     fbois@diana.lbl.gov
-
    -- Revisions -----
-     Logfile:  SCCS/s.yourcode.h
-    Revision:  1.7
-        Date:  14 Nov 1997
-     Modtime:  06:39:23
+     Logfile:  %F%
+    Revision:  %I%
+        Date:  %G%
+     Modtime:  %U%
       Author:  @a
    -- SCCS  ---------
 
@@ -40,14 +32,14 @@
 #ifndef _YOURCODE_H_
 #define _YOURCODE_H_
 
-/* -----------------------------------------------------------------------------
+/* ----------------------------------------------------------------------------
    Inclusions
 */
 
 #include "sim.h"
 
 
-/* -----------------------------------------------------------------------------
+/* ----------------------------------------------------------------------------
    Typedefs
 */
 
@@ -58,7 +50,7 @@ typedef struct tagMCPREDOUT {
 } MCPREDOUT, *PMCPREDOUT;
 
 
-/* -----------------------------------------------------------------------------
+/* ----------------------------------------------------------------------------
    Prototypes  */
 
 void DoStep_by_Step (void /* double t, long *neq, double *y */);
